@@ -16,7 +16,7 @@ sub run {
     # AIX need -a option
     for (`ifconfig -a`){#ifconfig in the path
         # AIX ligne inet
-        if(/^\s*inet\s+(\S+).*/){($1=~/^127.+/)?next:push @ip, $1};
+        if(/^\s*inet\s+(\S+).*/){($1=~/127.+/)?next:push @ip, $1};
     }
     $ip=join "/", @ip;
     $common->setHardware({IPADDR => $ip});
