@@ -154,6 +154,8 @@ sub run {
     }
 }
 
+1;
+
 sub getSpeed{
     my ($speed)=@_;
 
@@ -221,16 +223,13 @@ sub getRoute {
     return $route;
 }
 
-1;
-__END__
-
 =head1 NAME
 
-OCSInventory::Agent::Backend::OS::BSD::Networks - Network-related information
+OCSInventory::Agent::Backend::OS::BSD::Networks - Network-related informations
 
 =head1 DESCRIPTION
 
-This module retrieves network information.
+This module retrieves network informations.
 
 =head1 FUNCTIONS
 
@@ -242,18 +241,28 @@ Returns the speed of the card.
 
 Returns the gateway
 
+=back
+
 =head2 getIPNetmaskV4
 
 Returns the IP v4 network mask 
 
+=back
+
 =head2 getIPNetmaskV6
 
 Returns the IP v6 network mask 
 
+=back
+
 =head2 getSubnetAddressIPv4 
 
 Returns the subnet of ip v4 network
 
-=head2 getSubnetAddressIPv6 
+=back
+
+=head getSubnetAddressIPv6 
 
 Returns the subnet of ip v6 network
+
+=back
