@@ -18,9 +18,8 @@ sub run {
 
     my $equery_vers = `equery --version ` =~ /.*\((.*)\).*/;
     $equery_vers = $1;
-    my ($major,$minor)=$equery_vers=~/(\d+)\.(\d+)\.\d+/;
 
-    if ($minor ge 3) {
+    if ($equery_vers =~ /^0.3/) {
         foreach (`equery list --format='\$cp \$fullversion' '*'`){
             if (/^(.*) (.*)/) {
                 $common->addSoftware({
