@@ -11,6 +11,7 @@ sub check {
 
 sub run {
 
+    my $v;
     my $name;
     my $version;
     my $description;
@@ -30,25 +31,12 @@ sub run {
 
     # Debian version number is set in/etc/debian_version file
     if (-r "/etc/debian_version") {
-        if (`uname -v` =~ /debian/i) {
-            open V, "/etc/debian_version" or warn;
-            foreach (<V>) {
-                $version = $1 if ($_ =~ /^(\d+.*)/);
-            }
-            close V;
-            chomp($version);
-	}
-    }
-
-    # CentOS exact version number is set in /etc/centos-release file
-    if (-r "/etc/centos-release") {
-        open V, "/etc/centos-release" or warn;
-        foreach ($description=<V>) {
-            $version = $1 if ($_ =~ /(\d+\.\d+)./g);
+        open V, "/etc/debian_version" or warn;
+        foreach (<V>) {
+            $version = $1 if ($_ =~ /^(\d+.*)/);
         }
         close V;
         chomp($version);
-        chomp($description);
     }
 
     $common->setHardware({
