@@ -17,7 +17,7 @@ sub run {
     if ($common->can_run("ip")){
         foreach (`ip a`){
             if (/inet (\S+)\/\d{1,2}/){
-                ($1=~/^127.+/)?next:push @ip,$1;
+                ($1=~/127.+/)?next:push @ip,$1;
             } elsif (/inet6 (\S+)\d{2}/){
                 ($1=~/::1\/128/)?next:push @ip6, $1;
             }
@@ -26,7 +26,7 @@ sub run {
         foreach (`ifconfig`){
             #if(/^\s*inet\s*(\S+)\s*netmask/){
             if (/^\s*inet add?r\s*:\s*(\S+)/ || /^\s*inet\s+(\S+)/){
-                ($1=~/^127.+/)?next:push @ip, $1;
+                ($1=~/127.+/)?next:push @ip, $1;
             } elsif (/^\s*inet6\s+(\S+)/){
                 ($1=~/::1/)?next:push @ip6, $1;
             }
