@@ -200,7 +200,7 @@ sub addInput {
 
     my $content = {};
 
-    foreach my $key (qw/DESCRIPTION INTERFACE MANUFACTURER CAPTION POINTTYPE TYPE/) {
+    foreach my $key (qw/DESCRIPTION INTERFACE MANUFACTURER SERIAL TYPE/) {
         if (exists $args->{$key}) {
             $content->{$key}[0] = $args->{$key} if $args->{$key};
         }
@@ -509,7 +509,7 @@ sub setHardware {
 
     foreach my $key (qw/USERID OSVERSION PROCESSORN OSCOMMENTS CHECKSUM
     PROCESSORT NAME PROCESSORS SWAP ETIME TYPE OSNAME IPADDR WORKGROUP
-    DESCRIPTION MEMORY UUID DNS LASTLOGGEDUSER INSTALLDATE
+    DESCRIPTION MEMORY UUID DNS LASTLOGGEDUSER
     DATELASTLOGGEDUSER DEFAULTGATEWAY VMSYSTEM/) {
 
         if (exists $args->{$key}) {
@@ -598,7 +598,7 @@ sub addLocalUser {
 
     my $content = {};
 
-    foreach my $key (qw/GID HOME ID_USER LOGIN NAME SHELL/) {
+    foreach my $key (qw/GID HOME ID LOGIN NAME SHELL/) {
         if (exists $args->{$key}) {
             $content->{$key}[0] = $args->{$key} if $args->{$key};
         }
@@ -614,7 +614,7 @@ sub addLocalGroup {
 
     my $content = {};
 
-    foreach my $key (qw/ID_GROUP MEMBER NAME/) {
+    foreach my $key (qw/ID MEMBER NAME/) {
         if (exists $args->{$key}) {
             $content->{$key}[0] = $args->{$key} if $args->{$key};
         }
@@ -1050,7 +1050,6 @@ sub cleanXml {
     my $logger = $self->{logger};
 
     my $clean_content = encode('UTF-8', $content, Encode::FB_DEFAULT | Encode::LEAVE_SRC | Encode::FB_XMLCREF);
-    $clean_content =~ tr/\x00-\x08\x0B\x0C\x0E-\x1F//d;  # remove forbidden char in XML
 
     $logger->debug("cleanXml changed content") if ($content ne $clean_content);
 
