@@ -11,8 +11,6 @@ use Socket;
 use Ocsinventory::Compress;
 use Ocsinventory::Agent::Encrypt;
 
-#$XML::Simple::PREFERRED_PARSER = 'XML::Parser';
-
 sub new {
     my (undef, $params) = @_;
 
@@ -50,7 +48,7 @@ sub new {
         $self->{ua}->env_proxy;
     }
     my $version = 'OCS-NG_unified_unix_agent_v';
-    $version .= exists ($self->{config}->{version})?$self->{config}->{version}:'';
+    $version .= exists ($self->{config}->{VERSION})?$self->{config}->{VERSION}:'';
     my $userencrypt = Ocsinventory::Agent::Encrypt::getClearText($self->{config}->{user});
     my $pwdencrypt = Ocsinventory::Agent::Encrypt::getClearText($self->{config}->{password});
     $self->{ua}->agent($version);
@@ -100,20 +98,6 @@ sub sendXML {
     $req->header('Pragma' => 'no-cache', 'Content-type',
       'application/x-compress');
 
-    if (! $self->{config}{force}) {
-      # Checking if XML is valid before submitting
-      $logger->debug ("checking XML");
-
-      eval { XML::Simple::XMLin( $message ) };
-      if($@) {
-        my $xml_error = $@;
-        $xml_error =~ s/^\n//;
-        $logger->error ('Invalid XML: '.$xml_error);
-        $logger->error ('Cannot submit XML! Abort...');
-        return;
-      }
-    }
-
     $logger->debug ("sending XML");
 
     $logger->debug ("sending: ".$message);
