@@ -26,7 +26,6 @@ my $nossl;
 my $download;
 my $snmp;
 my $now;
-my $nosoftware;
 
 
 for $option (@ARGV){
@@ -62,8 +61,6 @@ for $option (@ARGV){
         $config->{ca} = $1;
     } elsif($option=~/--download$/){
         $download = 1;
-    } elsif($option=~/--nosoftware$/){
-        $nosoftware = 1;
     } elsif($option=~/--snmp$/){
         $config->{snmp} = 1;
     } elsif($option=~/--now$/){
@@ -85,7 +82,6 @@ Usage :
 \t--logfile=path                set OCS Inventory NG Unix Unified agent log file path (if needed) 
 \t--nossl                       disable SSL CA verification configuration option while installing OCS Inventory NG Unix Unified agent (not recommended)
 \t--ca=path                     set OCS Inventory NG Unix Unified agent CA certificates file path
-\t--nosoftware                  disable software inventory
 \t--download                    activate package deployment feature while installing OCS Inventory NG Unix Unified agent
 \t--snmp                        activate SNMP scans feature while installing OCS Inventory NG Unix Unified agent
 \t--now                         launch OCS Inventory NG Unix Unified agent after installation
@@ -109,24 +105,14 @@ unless ($config->{basevardir}) {
     } elsif ($^O =~ /bsd/) {
         $config->{basevardir} = '/var/db/ocsinventory-agent';
     } else { 
-        $config->{basevardir} = '/var/lib/ocsinventory-agent';
+        $config->{basevardir} = '/var/lib/ocsinventory-agent'
     }
 }
 
-# Default value of SNMP timeout
-unless ($config->{snmptimeout}) {
-    $config->{snmptimeout} = 3;
-}
-
-# Default value of SNMP retry
-unless ($config->{snmpretry}) {
-    $config->{snmpretry} = 2;
-}
-
 
 ############ Asking for questions ##############
 unless ($nowizard) {
-    if (!ask_yn("Do you want to configure the agent?", 'y')) {
+    if (!ask_yn("Do you want to configure the agent", 'y')) {
          exit 0;
     }
   
@@ -145,7 +131,7 @@ unless ($nowizard) {
     }
 
     #Old unix agent
-    if (ask_yn("Should the old unix_agent settings be imported?", 'y')) {
+    if (ask_yn("Should the old unix_agent settings be imported ?", 'y')) {
         $old_unix_config=1;
     }
 
@@ -186,18 +172,18 @@ unless ($nowizard) {
 
     #Getting tag
     unless ($config->{tag}){
-        if (ask_yn('Do you want to apply an administrative tag on this machine?', 'y')) {
+        if (ask_yn('Do you want to apply an administrative tag on this machine', 'y')) {
             $config->{tag} = promptUser("tag", $config->{tag});
         }
     }
 
     #Getting crontab
     if ($^O =~ /solaris/ || $^O =~ /bsd/) {
-        if (ask_yn("Do yo want to install the cron task in current user crontab?", 'y')) {
+        if (ask_yn("Do yo want to install the cron task in current user crontab ?", 'y')) {
             $crontab = 1;
         }
     } elsif (-d "/etc/cron.d") {
-        if (ask_yn("Do yo want to install the cron task in /etc/cron.d?", 'y')) {
+        if (ask_yn("Do yo want to install the cron task in /etc/cron.d", 'y')) {
             $crontab = 1;
         }
     }
@@ -212,34 +198,30 @@ unless ($nowizard) {
     }
 
     #Remove old unix agent ?
-    $remove_old_unix = ask_yn ("Should I remove the old unix_agent?", 'n') unless $remove_old_unix;
+    $remove_old_unix = ask_yn ("Should I remove the old unix_agent", 'n') unless $remove_old_unix;
 
     #Enable debug option ?
-    $config->{debug} = ask_yn("Do you want to activate debug configuration option?", 'y') unless $config->{debug};
+    $config->{debug} = ask_yn("Do you want to activate debug configuration option ?", 'y') unless $config->{debug};
 
     #Enable log file ?
     unless ($config->{logfile}) {
-        if (ask_yn("Do you want to use OCS Inventory NG UNix Unified agent log file?", 'y')){ 
+        if (ask_yn("Do you want to use OCS Inventory NG UNix Unified agent log file ?", 'y')){ 
             $config->{logfile} = promptUser('Specify log file path you want to use', $config->{logfile}, '^\/\w+', 'The location must begin with /');
         }
     }
 
     #Disable SSL option ?
     unless ($nossl) {
-        $nossl = ask_yn("Do you want disable SSL CA verification configuration option (not recommended)?", 'n');
+        $nossl = ask_yn("Do you want disable SSL CA verification configuration option (not recommended) ?", 'n');
     }
 
     #Set CA certificates file path ?
     unless ($config->{ca}) {
-        if (ask_yn("Do you want to set CA certificates file path?", 'y')){
+        if (ask_yn("Do you want to set CA certificates file path ?", 'y')){
             $config->{ca} = promptUser('Specify CA certificates file path', $config->{ca}, '^\/\w+', 'The location must begin with /');
         }
     }
 
-    #Disable software inventory ?
-    unless ($nosoftware) {
-        $nossl = ask_yn("Do you want disable software inventory?", 'n');
-    }
     #Enable download feature ?
     $download = ask_yn("Do you want to use OCS-Inventory software deployment feature?", 'y') unless $download;
 
@@ -364,13 +346,6 @@ if (!-d $config->{basevardir}) {
 #Disabling SSL verification if asked
 $config->{ssl} = 0 if $nossl;
 
-#Disabling software inventory 
-if ($nosoftware) {
-    $config->{nosoftware} = 1;
-} else {
-    $config->{nosoftware} = 0;
-}
-
 #Creating configuration directory 
 $configdir = "/etc/ocsinventory-agent" unless $configdir;  #If not set in command line
 
@@ -510,7 +485,7 @@ sub ask_yn {
         return 1 if $line =~ /^y$/;
         return if $line =~ /^n$/;
         if ($cpt-- < 0) {
-            print STDERR "too much user input, exit...\n";
+            print STDERR "to much user input, exit...\n";
             exit(0);
         }
     }
@@ -533,7 +508,7 @@ sub promptUser {
             last;
         }
         if ($cpt-- < 0) {
-            print STDERR "too much user input, exit...\n";
+            print STDERR "to much user input, exit...\n";
             exit(0);
         }
     }
